@@ -2,4 +2,5 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-print "Hello world"
+from __future__ import print_function
+print("Hello world")
